@@ -7,11 +7,7 @@
 #'
 #' @evalRd return_tidy(regression = TRUE)
 #'
-#' @examples
-#' 
-#' # feel free to ignore the following line—it allows {broom} to supply 
-#' # examples without requiring the model-supplying package to be installed.
-#' if (requireNamespace("bbmle", quietly = TRUE)) {
+#' @examplesIf rlang::is_installed("bbmle")
 #'
 #' # load libraries for models and data
 #' library(bbmle)
@@ -29,12 +25,12 @@
 #' # summarize model fit with tidiers
 #' tidy(fit)
 #' 
-#' }
-#' 
 #' @export
 #' @seealso [tidy()], [bbmle::mle2()], [tidy_optim()]
 #' @aliases mle2_tidiers bbmle_tidiers
 tidy.mle2 <- function(x, conf.int = FALSE, conf.level = .95, ...) {
+  check_ellipses("exponentiate", "tidy", "mle2", ...)
+  
   co <- bbmle::coef(bbmle::summary(x))
   ret <- ret <- as_tidy_tibble(
     co,
